@@ -140,7 +140,7 @@ class AudienceQuery(object):
             if not isinstance(argument, list):
                 raise InvalidQuery(f'The `{operator}` operator expects a list')
 
-            query = [cls.parse(q, allowed_fields=allowed_fields) for q in argument]
+            query = cls.parse(argument, allowed_fields=allowed_fields)
 
             return AudienceQuery(query, op_c1=operator, allowed_fields=allowed_fields)
 
@@ -152,10 +152,6 @@ class AudienceQuery(object):
         else:
             raise InvalidQuery(f'Unknown operator {operator}')
 
-        query = cls.parse(argument)
-
-        return AudienceQuery(query, op_c1=operator, allowed_fields=allowed_fields)
-
     @classmethod
     def parse_query_atom(cls,
                          field_name,
