@@ -17,6 +17,7 @@ DEFAULT_REDIS_CLIENT = None
 DEFAULT_DJANGO_PROFILE_MODEL = None
 DEFAULT_DJANGO_COUNT_FUNC = None
 DEFAULT_DJANGO_POINTER_MODEL = None
+DEFAULT_DJANGO_MAX_FUNC = None
 DEFAULT_DJANGO_CONNECTION_TUPLE = (None, None)
 DEFAULT_PROFILE_TTL = 12 * 60 * 60
 DEFAULT_PROFILE_TTL_MARGIN = 2 * 60 * 60
@@ -53,6 +54,7 @@ class Profile(object):
     django_pointer_model = DEFAULT_DJANGO_POINTER_MODEL
     django_connection_tuple = DEFAULT_DJANGO_CONNECTION_TUPLE
     django_count_func = DEFAULT_DJANGO_COUNT_FUNC
+    django_max_func = DEFAULT_DJANGO_MAX_FUNC
     profile_ttl = DEFAULT_PROFILE_TTL
     profile_ttl_margin = DEFAULT_PROFILE_TTL_MARGIN
     user_ttl = DEFAULT_USER_TTL
@@ -771,6 +773,18 @@ class Profile(object):
         result = cls.usable_django_model().objects.all().values('user_id').annotate(
             count=cls.django_count_func('user_id')).filter(count__gt=1).order_by()[start:start + num]
         return [str(res['user_id']) for res in result]
+    
+    @classmethod
+    def get_inactive_user_ids_from_db(cls,
+                                      max_age_days,
+                                      num,
+                                      start):
+
+        threshold = pytz.utc.localize(datetime.datetime.utcnow()) - datetime.timedelta(days=max_age_days)
+
+        result = cls.usable_django_model().objects.all().values('user_id').annotate(
+            max_modified=cls.django_max_func('modified')).filter(max_modified__lte=threshold).order_by()[start:start + num]
+        return [str(res['user_id']) for res in result]
 
     @classmethod
     def multiple_from_database(cls,
