@@ -125,10 +125,23 @@ class StitchPool(object):
     def lock(self, ttl):
         return Lock('sp' + str(self.user_id), self.redis_client, ttl=ttl * 1000)
 
+    def delete(self):
+
+        self.delete_from_cache()
+        self.delete_from_db()
+
     def delete_from_cache(self):
         self.redis_client.delete(self.key)
         self.redis_client.zrem(self.all_stitchpools_key, self.key)
 
+    def delete_from_db(self):
+
+        model = self.usable_django_model()
+        try:
+            stitch_pool_model = model.objects.get(user_id=self.user_id)
+            stitch_pool_model.delete()
+        except model.DoesNotExist:
+            pass
 
     def to_db(self):
 
@@ -427,6 +440,19 @@ class Stitch(object):
                     time.sleep(1 + random.random() / 10)
         raise error
 
+    def delete_from_db(self):
+
+        model = self.usable_django_model()
+        try:
+            stitch_model = model.objects.get(key=self.key)
+            stitch_model.delete()
+        except model.DoesNotExist:
+            pass
+
+    def delete(self):
+
+        self.delete_from_cache()
+        self.delete_from_db()
 
     @classmethod
     def from_redis_data(cls,
